import { AxiosError, type AxiosRequestConfig, type AxiosResponse } from 'axios';
import { Ref } from 'vue-demi';
export type MaybeRecord<T> = T & Record<string, unknown>;
export interface IResponse extends AxiosResponse {
    $config: IRequestConfig;
}
export interface IRequestConfig<T = any> extends Omit<AxiosRequestConfig, 'params' | 'data'> {
    withTimestamp?: boolean;
    isFilterEmpty?: boolean | Array<any>;
    header?: Record<string, any>;
    data?: T | Ref<T>;
    params?: T | Ref<T>;
    responseFields?: {
        data?: string;
        msg?: string;
        code?: string;
        [k: string]: any;
    };
    preRequest?: (config: IRequestConfig) => IRequestConfig;
    preResponse?: (response: IResponse) => MaybeRecord<IResponse> | void;
    errorHandler?: (err: AxiosError) => void;
}
export type OnSuccessCallback<T = any> = (callback: AxiosResponse<T>) => void;
export type OnCompletedCallback = () => void;
export type OnErrorCallback<T = any> = (callback: AxiosError<T>) => void;
export type MethodReturn<T = any, P = any> = {
    abort: () => void;
    data: Ref<T>;
    loading: Ref<boolean>;
    onSuccess: (callback: OnSuccessCallback<T>) => void;
    onCompleted: (callback: OnCompletedCallback) => void;
    onError: (callback: OnErrorCallback) => void;
    request: (parameter?: P) => Promise<void>;
};
export type RequestReturn<T = any, P = any> = {
    abort: () => void;
    request: (parameter?: P) => Promise<T>;
};
export type Options = {
    immediate?: boolean;
    key?: string;
};
export type Watcher<P> = {
    keys?: (keyof P)[];
    immediate?: boolean;
    deep?: boolean;
};
export type UsePagination<P = any, D = any> = {
    pageNumKey?: string;
    pageSizeKey?: string;
    handleParams?: (params: P) => P;
    watcher?: Watcher<P>;
    listKey?: string;
    totalKey?: string;
    hasPage?: (res: D) => boolean;
    append?: boolean;
    responseHandler?: (res: D) => any;
};
export type UsePaginationOptions<P = any, D = any> = UsePagination<P, D> & Options;
export type UsePaginationReturn<T = any, P extends object = any> = {
    params: Ref<P>;
    tableLoading: Ref<boolean>;
    tableData: Ref<T[]>;
    tableTotal: Ref<number>;
    isLastPage: Ref<boolean>;
    handleCurrentChange: (pageNum: number) => Promise<void>;
    handleSizeChange: (pageSize: number) => Promise<void>;
    handleSearch: (pageNum?: number) => Promise<void>;
    handleReset: () => Promise<void>;
} & Pick<RequestReturn, 'abort'>;
